#include <Wt/WVBoxLayout.h>
#include <Wt/WHBoxLayout.h>
#include <Wt/WCssDecorationStyle.h>
#include <Wt/WBorder.h>
#include <Wt/WColor.h>
#include <Wt/WSignal.h>
#include <Wt/WLogger.h>

#include "ViewTopLevel.h"

using namespace Wt;

  

ViewTopLevel::ViewTopLevel()
{
	int initialIndex =  static_cast<int>(CurrentTest::TEST_ID_0);
    this->setMaximumSize(1200, 1250);
	this->decorationStyle().setBorder(Wt::WBorder(Wt::BorderStyle::Double, Wt::BorderWidth::Thick, Wt::StandardColor::Black), AllSides);

	userLoginState = LoginState::STATE_LOGGED_IN;
	userFullName = Wt::WString("Mary John Doe");



	//Container1, this will contain various stacked items
	stackedItemContainer = this->addNew<Wt::WStackedWidget>();
	Wt::WAnimation animation(Wt::AnimationEffect::Fade, Wt::TimingFunction::Linear, 200);

    stackedItemContainer->setTransitionAnimation(animation, true);


	// Create the views and add them to stacked arrangement
	widget0 = stackedItemContainer->addNew<LoginRegisterWidget>(userFullName);
	widget1 = stackedItemContainer->addNew<ViewSample1Page>(userFullName);


    widget0->loginButtonClicked().connect(this, &ViewTopLevel::processLoginSignal);
    widget0->otherButtonClicked().connect(this, &ViewTopLevel::processSignalFromView);
 
	stackedItemContainer->setCurrentIndex(initialIndex);

}


void ViewTopLevel::processSignalFromView(ViewId whatView, SignalId whatSignal)
{
	switch (whatView)
	{
		case ViewId::VIEW_ID_LOGIN_REGISTER:
			processLoginViewSignals(whatSignal) ;

			break;


		case ViewId::VIEW_ID_IT_ADMIN_MAIN:
			log("info") << __FUNCTION__ << " Signal received from Sample page";
			break;

 
		default:   // Do nothing if we dont recognize source of signal
			break;

	}

}


// These will transition to another view to allow registration or password reset
void ViewTopLevel::processLoginViewSignals( SignalId whatSignal)
{

	switch (whatSignal)
	{
		case SignalId::SIGNAL_BTN_REGISTER_CLICKED:
			log("info") << "LoginRegisterView:" << "SIGNAL_BTN_REGISTER_CLICKED" << " received";
			stackedItemContainer->setCurrentIndex(1); // Switch to registration view
			break;

		case SignalId::SIGNAL_BTN_FORGOT_PWD_CLICKED:
			log("info") << "LoginRegisterView:" << "SIGNAL_BTN_FORGOT_PWD_CLICKED" << " received";
		  break;

		default:   // Do nothing if we dont recognize source of signal
			break;

	}    


}
  


void ViewTopLevel::processLoginSignal(std::string userId, std::string userPwd)
{
 
	log("info") << __FUNCTION__ << " SIGNAL_BTN_LOGIN_CLICKED" << " received";
	log("info") << __FUNCTION__ << " Pwd:=" << userPwd  <<  " UserId:= " << userId;

}




